# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/auditus',
                'doc_host': 'https://CarloLepelaars.github.io',
                'git_url': 'https://github.com/CarloLepelaars/auditus',
                'lib_path': 'auditus'},
  'syms': { 'auditus.core': { 'auditus.core.AudioArray': ('core.html#audioarray', 'auditus/core.py'),
                              'auditus.core.AudioArray.__getitem__': ('core.html#audioarray.__getitem__', 'auditus/core.py'),
                              'auditus.core.AudioArray.__init__': ('core.html#audioarray.__init__', 'auditus/core.py'),
                              'auditus.core.AudioArray.__len__': ('core.html#audioarray.__len__', 'auditus/core.py'),
                              'auditus.core.AudioArray.audio': ('core.html#audioarray.audio', 'auditus/core.py'),
                              'auditus.core.AudioArray.shape': ('core.html#audioarray.shape', 'auditus/core.py')},
            'auditus.transform': { 'auditus.transform.AudioEmbedding': ('transform.html#audioembedding', 'auditus/transform.py'),
                                   'auditus.transform.AudioEmbedding.__init__': ( 'transform.html#audioembedding.__init__',
                                                                                  'auditus/transform.py'),
                                   'auditus.transform.AudioEmbedding.call_model': ( 'transform.html#audioembedding.call_model',
                                                                                    'auditus/transform.py'),
                                   'auditus.transform.AudioEmbedding.encodes': ( 'transform.html#audioembedding.encodes',
                                                                                 'auditus/transform.py'),
                                   'auditus.transform.AudioLoader': ('transform.html#audioloader', 'auditus/transform.py'),
                                   'auditus.transform.AudioLoader.__init__': ( 'transform.html#audioloader.__init__',
                                                                               'auditus/transform.py'),
                                   'auditus.transform.AudioLoader.encodes': ('transform.html#audioloader.encodes', 'auditus/transform.py'),
                                   'auditus.transform.AudioLoader.load_audio': ( 'transform.html#audioloader.load_audio',
                                                                                 'auditus/transform.py'),
                                   'auditus.transform.AudioPipeline': ('transform.html#audiopipeline', 'auditus/transform.py'),
                                   'auditus.transform.AudioPipeline.__init__': ( 'transform.html#audiopipeline.__init__',
                                                                                 'auditus/transform.py'),
                                   'auditus.transform.Pooling': ('transform.html#pooling', 'auditus/transform.py'),
                                   'auditus.transform.Pooling.__init__': ('transform.html#pooling.__init__', 'auditus/transform.py'),
                                   'auditus.transform.Pooling.encodes': ('transform.html#pooling.encodes', 'auditus/transform.py'),
                                   'auditus.transform.Resampling': ('transform.html#resampling', 'auditus/transform.py'),
                                   'auditus.transform.Resampling.__init__': ('transform.html#resampling.__init__', 'auditus/transform.py'),
                                   'auditus.transform.Resampling._new_length': ( 'transform.html#resampling._new_length',
                                                                                 'auditus/transform.py'),
                                   'auditus.transform.Resampling.encodes': ('transform.html#resampling.encodes', 'auditus/transform.py'),
                                   'auditus.transform.Resampling.process_audio_array': ( 'transform.html#resampling.process_audio_array',
                                                                                         'auditus/transform.py')}}}
